==> moodle-1.5-mysql.tgz: moodle/lang/fi/survey.php <==
<?PHP // $Id$ 
      // survey.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005032600)


$string['actual'] = 'Toteutunut';
$string['actualclass'] = 'Toteutunut';
$string['actualstudent'] = '$a toteutunut';
$string['allquestions'] = 'Kaikki kysymykset jrjestyksess, kaikki opiskelijat';
$string['allscales'] = 'Kaikki asteikot, kaikki opiskelijat';
$string['alreadysubmitted'] = 'Olet jo palauttanut tmn kyselyn';
$string['analysisof'] = 'Analyysi $a';
$string['answers'] = 'Vastaukset';
$string['attls1'] = 'Kun arvioin, mit joku sanoo, keskityn argumenttien laatuun, en henkiln, joka esitt asian.';
$string['attls10'] = 'Minulle on trke pysy mahdollisimman objektiivisena, kun arvion jotain.';
$string['attls10short'] = 'pysy objektiivisena';
$string['attls11'] = 'Yritn ajatella yhdess ihmisten kanssa, enk heit vastaan.';
$string['attls11short'] = 'ajattele yhdess ihmisten kanssa';
$string['attls12'] = 'Kytn tiettyj kriteerej arvioidessani perusteluja.';
$string['attls12short'] = 'kyt kriteerej arviointiin';
$string['attls13'] = 'Mieluummin yritn ymmrt toisen mielipiteen, kuin arvioida sit.';
$string['attls13short'] = 'yrit ymmrt';
$string['attls14'] = 'Yritn osoittaa heikot kohdat muiden ajattelussa auttaakseni heit selventmn perustelunsa.';
$string['attls14short'] = 'osoita heikkoudet';
$string['attls15'] = 'Yritn ajatella itseni toisen asemaan ristiriitatilanteissa nhdkseni miksi he ajattelevat niin kuin ajattelevat.';
$string['attls15short'] = 'asetu toisen asemaan';
$string['attls16'] = 'Pyrin vertaamaan huolellisesti kaikki asiaan liittyvt nkkohdat ja faktat.';
$string['attls16short'] = 'vertaa faktoja';
$string['attls17'] = 'Arvostan loogisuutta yli assosioivan tietojen yhdistmisen ratkoessani ongelmia.';
$string['attls17short'] = 'arvostan loogisuutta';
$string['attls18'] = 'Kykenen empatian avulla oivaltamaan mielipiteit, joka eroavat omistani.';
$string['attls18short'] = 'oivalla empaattisesti';
$string['attls19'] = 'Kun henkiln mielipiteet ovat outoja minulle, pyrin laajentamaan ajatteluani ja ymmprtmn, miten hn voi ajatella niin.';
$string['attls19short'] = 'laajenna ajattelua';
$string['attls1short'] = 'keskity perustelujen laatuun';
$string['attls2'] = 'Haluan olla \'paholaisen asianajaja\', puolustaa vastakohtaa toisten vitteille.';
$string['attls20'] = 'Kytn aikaa lytkseni virheet. Etsin vaikka kirjallisesta ilmaisusta kohtia, joita ei ole ilmaistu hyvin.';
$string['attls20short'] = 'mik on vialla?';
$string['attls2short'] = 'Leiki \"paholaisen asianajajaa\"';
$string['attls3'] = 'Yritn ymmrt ihmisten taustat ja sen, mik saa heidt tuntemaan niin kuin he tuntevat.';
$string['attls3short'] = 'Ihmisten taustat';
$string['attls4'] = 'Trkein osa koulutustani on ollut oppia ymmrtmn toisenlaisia ihmisi.';
$string['attls4short'] = 'ymmrr toisenlaisia ihmisi';
$string['attls5'] = 'Uskon lytvni oman identiteetini paremmin keskustelemalla erilaisten ihmisten kanssa.';
$string['attls5short'] = 'keskustele useiden ihmisten kanssa';
$string['attls6'] = 'Nautin taustoiltaan erilaisten ihmisten mielipiteiden kuulumisesta, se auttaa minua ymmrtmmn, miten sama asian voi nhd eritavoin.';
$string['attls6short'] = 'nauti mielipiteiden kuulemisesta';
$string['attls7'] = 'Olen huomannut, ett voin vahvistaa asemaani vittelemll, jos joku on eri mielt kuin min.';
$string['attls7short'] = 'vahvistu vittelemll';
$string['attls8'] = 'Olen aina kiinnostunut, miksi ihmiset sanovat ja uskovat niin kuin tekevt.';
$string['attls8short'] = 'tied miksi ihmiset tekevt';
$string['attls9'] = 'Lukiessani kirjaa lydn itseni usein vittelemst kirjoittajan kanssa lytkseni kohdat, miss he ovat vrss.';
$string['attls9short'] = 'kyseenalasta kirjoittajat';
$string['attlsintro'] = 'Tmn kyselyn tarkoituksena on kartoitaa suhtautumistasi ajatteluun ja oppimiseen.

Kyselyyn ei ole olemassa oikeita tai vri vastuksia, vain sinun mielipiteesi on kiinnostava. Muista, ett vastaukset ksitelln luottamuksellisesti, eivtk ne vaikuta arvosteluun.';
$string['attlsm1'] = 'Asenne ajatteluun ja oppimiseen';
$string['attlsm2'] = 'Sosiaalinen oppiminen';
$string['attlsm3'] = 'Eristyv oppiminen';
$string['attlsmintro'] = 'Keskustelussa ...';
$string['attlsname'] = 'ATTLS (kysely asenteista oppimiseen ja ajatteluun, 20 kysymyst)';
$string['ciq1'] = 'Milloin tunsit olevasi kaikkein sitoutunein opiskeluun?';
$string['ciq1short'] = 'Sitoutunein';
$string['ciq2'] = 'Milloin tunsit olevasi kaikkein vhiten sitoutunut opiskeluun?';
$string['ciq2short'] = 'Vhiten sitoutunut';
$string['ciq3'] = 'Mik keskusteluissa ollut asia oli mielestsi eniten avuksi tai hydyllinen?';
$string['ciq3short'] = 'Hydyllinen hetki';
$string['ciq4'] = 'Mik keskusteluissa ollut asia oli mielestsi hankala tai hmmentv?';
$string['ciq4short'] = 'Hmmentv hetki';
$string['ciq5'] = 'Mik tapahtuma ylltti sinua eniten?';
$string['ciq5short'] = 'Yllttv hetki';
$string['ciqintro'] = 'Mieti kurssin aikana sattuneita tapahtumia ja vastaa alla oleviin kysymyksiin.';
$string['ciqname'] = 'Kriittiset tapahtumat';
$string['clicktocontinue'] = 'Klikkaa tst jatkaaksesi';
$string['clicktocontinuecheck'] = 'Klikkaa tst jatkaaksesi';
$string['colles1'] = 'oppiseni keskittyy asioihin, jotka kiinnostavat minua';
$string['colles10'] = 'kyselen muiden opiskelijoiden ajatuksia ja ideoita';
$string['colles10short'] = 'kysyn listietoja';
$string['colles11'] = 'muut opiskelijat kysyvt ajauksiani ja ideoitani';
$string['colles11short'] = 'muut kysyvt minulta';
$string['colles12'] = 'muut opiskelijat vastaavat ideoihini';
$string['colles12short'] = 'opiskelijat vastaavat minulle';
$string['colles13'] = 'ohjaaja lis omaan ajatteluani';
$string['colles13short'] = 'ohjaaja lis ajattelua';
$string['colles14'] = 'ohjaaja rohkaisee minua ottamaan osaa';
$string['colles14short'] = 'ohjaaja rohkaisee minua';
$string['colles15'] = 'ohjaaja pit hyvi esitelmi';
$string['colles15short'] = 'ohjaaja pit esitelmi';
$string['colles16'] = 'ohjaaja tukee kriittist itsearviointia';
$string['colles16short'] = 'ohjaaja tukee itsearviointia';
$string['colles17'] = 'toisen opiskelijat rohkaisevat minua osallistumaan';
$string['colles17short'] = 'opiskelija rohkaisevat minua';
$string['colles18'] = 'toiset opiskelijat kehuvat osallistumiistani';
$string['colles18short'] = 'opiskelijat kehuvat minua';
$string['colles19'] = 'toiset opiskelijat arvostavat osallistumistani';
$string['colles19short'] = 'opiskelijat arvostavat minua';
$string['colles1short'] = 'keskity kiinnostaviin asioihin';
$string['colles2'] = 'opin asioita, joista on ammatillista hyty';
$string['colles20'] = 'toiset opiskelijat tukevat yritystni oppia';
$string['colles20short'] = 'opiskelijat tukevat';
$string['colles21'] = 'saan hyvin selv muiden opiskelijoiden viesteist';
$string['colles21short'] = 'ymmrrn muita opiskelijoita';
$string['colles22'] = 'muut opiskelijat ymmrtvt viestini';
$string['colles22short'] = 'opiskelijat ymmrtvt minua';
$string['colles23'] = 'ymmrrn hyvin ohjaajan viestit';
$string['colles23short'] = 'ymmrrn ohjaajaa';
$string['colles24'] = 'ohjaaja ymmrt hyvin viestini';
$string['colles24short'] = 'ohjaaja ymmrt minua';
$string['colles2short'] = 'trkeit minulle kytnnss';
$string['colles3'] = 'opin, kuinka list ammatillista osaamistani';
$string['colles3short'] = 'list osaamistani';
$string['colles4'] = 'oppimani liittyy hyvin ammatilliseen kytntn';
$string['colles4short'] = 'liittyy kytntn';
$string['colles5'] = 'olen kriittinen siit kuinka opin';
$string['colles5short'] = 'olen kriittinen oppimisestani';
$string['colles6'] = 'ajattelen kriittisesti ideoitani';
$string['colles6short'] = 'olen kriittinen omien ideoitteni suhteen';
$string['colles7'] = 'Olen krittinen muiden opiskelijoiden ideoiden suhteen.';
$string['colles7short'] = 'Olen kriittinen muiden opiskelijoiden suhteen';
$string['colles8'] = 'Lukiessani olen krittinen kirjoittajan ideoiden suhteen.';
$string['colles8short'] = 'Olen kriittinen lukemani suhteen';
$string['colles9'] = 'Selitn ideani muille opiskelijoille';
$string['colles9short'] = 'Selitn ideani';
$string['collesaintro'] = 'Tmn kyselyn tarkoituksena on selvitt, kuinka hyvin tm online-kurssi on auttanut sinua oppimaan.

Jokainen seuravista 24 kysymyksest koskee sinun kokemuksiasi tll kursilla.

Ei ole olemassa oikeata tai vri vastauksia, tahdomme sinun mielipiteesi asioista. Muista ett vastaukset ksitelln luottamuksellisesti, eivtk ne vaikuta arvosteluun.

Vastaamalla huolellisesti ja ajatuksella autat meit parantamaan tt kurssia tulevaisuudessa.

Kiitokset avustasi.';
$string['collesaname'] = 'COLLES toteutunut (actual)';
$string['collesapintro'] = 'Tmn kyselyn tarkoituksena on selvitt kuinka hyvin tm online-kurssi on auttanut sinua oppimaan.

Jokainen seuravista 24 kysymyksest pyyt sina vertaamaan <i>ideaalia</i> ja <i>toteutunutta</i> tilannetta kurssilla.

Ei ole olemassa oikeata tai vri vastauksia, tahdomme sinun mielipiteesi asioista. Muista, ett vastaukset ksitelln luottamuksellisesti, eivtk ne vaikuta arvosteluun.

Vastaamalla huolellisesti ja ajatuksella autat meit parantamaan tt kurssia tulevaisuudessa.';
$string['collesapname'] = 'COLLES (Haluttu ja Toteutunut)';
$string['collesm1'] = 'Relevanssi';
$string['collesm1short'] = 'Relevanssi';
$string['collesm2'] = 'Heijastuminen';
$string['collesm2short'] = 'Heijastuminen';
$string['collesm3'] = 'Vuorovaikutteisuus';
$string['collesm3short'] = 'Vuorovaikutteisuus';
$string['collesm4'] = 'Ohjaajan tuki';
$string['collesm4short'] = 'Ohjaajan tuki';
$string['collesm5'] = 'Vertaistuki';
$string['collesm5short'] = 'Vertaistuki';
$string['collesm6'] = 'Tulkinta';
$string['collesm6short'] = 'Tulkinta';
$string['collesmintro'] = 'Tll kurssilla ...';
$string['collespintro'] = 'Tmn kyselyn tarkoituksena on selvit, mit asiaoita arvostat online-oppimisympristss.

Jokainen seuraavasta 24 kysymyksest kysyy sinun  odotuksistasi tlt kurssilta.
Ei ole olemassa oikeata tai vri vastauksia, tahdomme sinun mielipiteesi asioista. Muista ett vastaukset ksitelln luottamuksellisesti, eivtk ne vaikuta arvosteluun.

Vastaamalla huolellisesti ja ajatuksella autat meit parantamaan tt kurssia tulevaisuudessa.';
$string['collespname'] = 'COLLES haluttu (preferred) ';
$string['done'] = 'Tehty';
$string['download'] = 'Lataa';
$string['downloadexcel'] = 'Lataa tiedot Excel-taulukkona';
$string['downloadinfo'] = 'Voit ladata kaikki kyselyn tiedot analysointia varten. Voit kytt tietoja Excel-, SPPS- tai muussa ohjelmissa.';
$string['downloadtext'] = 'Lataa tiedot tekstitiedostona.';
$string['editingasurvey'] = 'Kyselynn muokkaus';
$string['guestsnotallowed'] = 'Kysely ei ole tarkoitettu vieraille';
$string['helpsurveys'] = 'Opastus eri kyselytyyppeihin';
$string['howlong'] = 'Kauanko sinulta meni aikaa kyselyyn vastaamiseen?';
$string['howlongoptions'] = 'alle 1 min,1-2 min,2-3 min,3-4 min,4-5-min,5-10 min,yli 10 min';
$string['ifoundthat'] = 'Huomasin tll kursilla, ett';
$string['introtext'] = 'Johdanto';
$string['ipreferthat'] = 'Olisi hyv, ett';
$string['modulename'] = 'Kysely';
$string['modulenameplural'] = 'Kyselyt';
$string['name'] = 'Nimi';
$string['newsurveyresponses'] = 'Uudet kyselyn vastaukset';
$string['nobodyyet'] = 'Kukaan ei ole viel vastannut kyselyyn';
$string['notdone'] = 'Suorittamatta';
$string['notes'] = 'Oma (henkilkohtainen) analyysisi ja muistiinpanosi.';
$string['othercomments'] = 'Onko sinulla muita kommentteja?';
$string['peoplecompleted'] = '$a henkil on suorittanut tmn kyselyn';
$string['preferred'] = 'Haluttu';
$string['preferredclass'] = 'Haluttu';
$string['preferredstudent'] = '$a haluttu';
$string['question'] = 'Kysymys';
$string['questions'] = 'Kysymykset';
$string['questionsnotanswered'] = 'Joihinkin monivalintoihin ei ole vastattu.';
$string['report'] = 'Kyselyn raportti';
$string['savednotes'] = 'Muistiinpanosi tallennettiin';
$string['scaleagree5'] = 'Vahvasti erimielt, Jotakuinkin erimielt, Ei samaa tai eri mielt, Jotakuinkin samaa mielt, Vahvasti samaa mielt';
$string['scales'] = 'Asteikot';
$string['scaletimes5'] = 'Ei koskaan, Harvoin, Joskus, Usein, Miltei aina';
$string['seemoredetail'] = 'Klikkaa tst nhdksesi listietoja ';
$string['selectedquestions'] = 'Valitut kysymykset, kaikki opiskelijat';
$string['summary'] = 'Yhteenveto';
$string['surveycompleted'] = 'Olet vastannut thn kyselyyn. Alla olevasta kuvasta net yhteenvedon vastauksistasi verrattuna kurssin keskiarvoon.';
$string['surveyname'] = 'Kyselyn nimi';
$string['surveysaved'] = 'Kysely tallennettu';
$string['surveytype'] = 'Kyselyn tyyppi';
$string['thanksforanswers'] = 'Kiitos vastauksestasi thn kyselyyn, $a';
$string['time'] = 'Aika';
$string['viewsurveyresponses'] = 'Katso $a kyselyn vastausta';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/fi/survey.php <==
<?PHP // $Id$ 
      // survey.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005032600)


$string['actual'] = 'Toteutunut';
$string['actualclass'] = 'Toteutunut';
$string['actualstudent'] = '$a toteutunut';
$string['allquestions'] = 'Kaikki kysymykset jrjestyksess, kaikki opiskelijat';
$string['allscales'] = 'Kaikki asteikot, kaikki opiskelijat';
$string['alreadysubmitted'] = 'Olet jo palauttanut tmn kyselyn';
$string['analysisof'] = 'Analyysi $a';
$string['answers'] = 'Vastaukset';
$string['attls1'] = 'Kun arvioin, mit joku sanoo, keskityn argumenttien laatuun, en henkiln, joka esitt asian.';
$string['attls10'] = 'Minulle on trke pysy mahdollisimman objektiivisena, kun arvion jotain.';
$string['attls10short'] = 'pysy objektiivisena';
$string['attls11'] = 'Yritn ajatella yhdess ihmisten kanssa, enk heit vastaan.';
$string['attls11short'] = 'ajattele yhdess ihmisten kanssa';
$string['attls12'] = 'Kytn tiettyj kriteerej arvioidessani perusteluja.';
$string['attls12short'] = 'kyt kriteerej arviointiin';
$string['attls13'] = 'Mieluummin yritn ymmrt toisen mielipiteen, kuin arvioida sit.';
$string['attls13short'] = 'yrit ymmrt';
$string['attls14'] = 'Yritn osoittaa heikot kohdat muiden ajattelussa auttaakseni heit selventmn perustelunsa.';
$string['attls14short'] = 'osoita heikkoudet';
$string['attls15'] = 'Yritn ajatella itseni toisen asemaan ristiriitatilanteissa nhdkseni miksi he ajattelevat niin kuin ajattelevat.';
$string['attls15short'] = 'asetu toisen asemaan';
$string['attls16'] = 'Pyrin vertaamaan huolellisesti kaikki asiaan liittyvt nkkohdat ja faktat.';
$string['attls16short'] = 'vertaa faktoja';
$string['attls17'] = 'Arvostan loogisuutta yli assosioivan tietojen yhdistmisen ratkoessani ongelmia.';
$string['attls17short'] = 'arvostan loogisuutta';
$string['attls18'] = 'Kykenen empatian avulla oivaltamaan mielipiteit, joka eroavat omistani.';
$string['attls18short'] = 'oivalla empaattisesti';
$string['attls19'] = 'Kun henkiln mielipiteet ovat outoja minulle, pyrin laajentamaan ajatteluani ja ymmprtmn, miten hn voi ajatella niin.';
$string['attls19short'] = 'laajenna ajattelua';
$string['attls1short'] = 'keskity perustelujen laatuun';
$string['attls2'] = 'Haluan olla \'paholaisen asianajaja\', puolustaa vastakohtaa toisten vitteille.';
$string['attls20'] = 'Kytn aikaa lytkseni virheet. Etsin vaikka kirjallisesta ilmaisusta kohtia, joita ei ole ilmaistu hyvin.';
$string['attls20short'] = 'mik on vialla?';
$string['attls2short'] = 'Leiki \"paholaisen asianajajaa\"';
$string['attls3'] = 'Yritn ymmrt ihmisten taustat ja sen, mik saa heidt tuntemaan niin kuin he tuntevat.';
$string['attls3short'] = 'Ihmisten taustat';
$string['attls4'] = 'Trkein osa koulutustani on ollut oppia ymmrtmn toisenlaisia ihmisi.';
$string['attls4short'] = 'ymmrr toisenlaisia ihmisi';
$string['attls5'] = 'Uskon lytvni oman identiteetini paremmin keskustelemalla erilaisten ihmisten kanssa.';
$string['attls5short'] = 'keskustele useiden ihmisten kanssa';
$string['attls6'] = 'Nautin taustoiltaan erilaisten ihmisten mielipiteiden kuulumisesta, se auttaa minua ymmrtmmn, miten sama asian voi nhd eritavoin.';
$string['attls6short'] = 'nauti mielipiteiden kuulemisesta';
$string['attls7'] = 'Olen huomannut, ett voin vahvistaa asemaani vittelemll, jos joku on eri mielt kuin min.';
$string['attls7short'] = 'vahvistu vittelemll';
$string['attls8'] = 'Olen aina kiinnostunut, miksi ihmiset sanovat ja uskovat niin kuin tekevt.';
$string['attls8short'] = 'tied miksi ihmiset tekevt';
$string['attls9'] = 'Lukiessani kirjaa lydn itseni usein vittelemst kirjoittajan kanssa lytkseni kohdat, miss he ovat vrss.';
$string['attls9short'] = 'kyseenalasta kirjoittajat';
$string['attlsintro'] = 'Tmn kyselyn tarkoituksena on kartoitaa suhtautumistasi ajatteluun ja oppimiseen.

Kyselyyn ei ole olemassa oikeita tai vri vastuksia, vain sinun mielipiteesi on kiinnostava. Muista, ett vastaukset ksitelln luottamuksellisesti, eivtk ne vaikuta arvosteluun.';
$string['attlsm1'] = 'Asenne ajatteluun ja oppimiseen';
$string['attlsm2'] = 'Sosiaalinen oppiminen';
$string['attlsm3'] = 'Eristyv oppiminen';
$string['attlsmintro'] = 'Keskustelussa ...';
$string['attlsname'] = 'ATTLS (kysely asenteista oppimiseen ja ajatteluun, 20 kysymyst)';
$string['ciq1'] = 'Milloin tunsit olevasi kaikkein sitoutunein opiskeluun?';
$string['ciq1short'] = 'Sitoutunein';
$string['ciq2'] = 'Milloin tunsit olevasi kaikkein vhiten sitoutunut opiskeluun?';
$string['ciq2short'] = 'Vhiten sitoutunut';
$string['ciq3'] = 'Mik keskusteluissa ollut asia oli mielestsi eniten avuksi tai hydyllinen?';
$string['ciq3short'] = 'Hydyllinen hetki';
$string['ciq4'] = 'Mik keskusteluissa ollut asia oli mielestsi hankala tai hmmentv?';
$string['ciq4short'] = 'Hmmentv hetki';
$string['ciq5'] = 'Mik tapahtuma ylltti sinua eniten?';
$string['ciq5short'] = 'Yllttv hetki';
$string['ciqintro'] = 'Mieti kurssin aikana sattuneita tapahtumia ja vastaa alla oleviin kysymyksiin.';
$string['ciqname'] = 'Kriittiset tapahtumat';
$string['clicktocontinue'] = 'Napsauta tst jatkaaksesi';
$string['clicktocontinuecheck'] = 'Napsauta tst jatkaaksesi';
$string['colles1'] = 'oppiseni keskittyy asioihin, jotka kiinnostavat minua';
$string['colles10'] = 'kyselen muiden opiskelijoiden ajatuksia ja ideoita';
$string['colles10short'] = 'kysyn listietoja';
$string['colles11'] = 'muut opiskelijat kysyvt ajauksiani ja ideoitani';
$string['colles11short'] = 'muut kysyvt minulta';
$string['colles12'] = 'muut opiskelijat vastaavat ideoihini';
$string['colles12short'] = 'opiskelijat vastaavat minulle';
$string['colles13'] = 'ohjaaja lis omaan ajatteluani';
$string['colles13short'] = 'ohjaaja lis ajattelua';
$string['colles14'] = 'ohjaaja rohkaisee minua ottamaan osaa';
$string['colles14short'] = 'ohjaaja rohkaisee minua';
$string['colles15'] = 'ohjaaja pit hyvi esitelmi';
$string['colles15short'] = 'ohjaaja pit esitelmi';
$string['colles16'] = 'ohjaaja tukee kriittist itsearviointia';
$string['colles16short'] = 'ohjaaja tukee itsearviointia';
$string['colles17'] = 'toisen opiskelijat rohkaisevat minua osallistumaan';
$string['colles17short'] = 'opiskelija rohkaisevat minua';
$string['colles18'] = 'toiset opiskelijat kehuvat osallistumiistani';
$string['colles18short'] = 'opiskelijat kehuvat minua';
$string['colles19'] = 'toiset opiskelijat arvostavat osallistumistani';
$string['colles19short'] = 'opiskelijat arvostavat minua';
$string['colles1short'] = 'keskity kiinnostaviin asioihin';
$string['colles2'] = 'opin asioita, joista on ammatillista hyty';
$string['colles20'] = 'toiset opiskelijat tukevat yritystni oppia';
$string['colles20short'] = 'opiskelijat tukevat';
$string['colles21'] = 'saan hyvin selv muiden opiskelijoiden viesteist';
$string['colles21short'] = 'ymmrrn muita opiskelijoita';
$string['colles22'] = 'muut opiskelijat ymmrtvt viestini';
$string['colles22short'] = 'opiskelijat ymmrtvt minua';
$string['colles23'] = 'ymmrrn hyvin ohjaajan viestit';
$string['colles23short'] = 'ymmrrn ohjaajaa';
$string['colles24'] = 'ohjaaja ymmrt hyvin viestini';
$string['colles24short'] = 'ohjaaja ymmrt minua';
$string['colles2short'] = 'trkeit minulle kytnnss';
$string['colles3'] = 'opin, kuinka list ammatillista osaamistani';
$string['colles3short'] = 'list osaamistani';
$string['colles4'] = 'oppimani liittyy hyvin ammatilliseen kytntn';
$string['colles4short'] = 'liittyy kytntn';
$string['colles5'] = 'olen kriittinen siit kuinka opin';
$string['colles5short'] = 'olen kriittinen oppimisestani';
$string['colles6'] = 'ajattelen kriittisesti ideoitani';
$string['colles6short'] = 'olen kriittinen omien ideoitteni suhteen';
$string['colles7'] = 'Olen krittinen muiden opiskelijoiden ideoiden suhteen.';
$string['colles7short'] = 'Olen kriittinen muiden opiskelijoiden suhteen';
$string['colles8'] = 'Lukiessani olen krittinen kirjoittajan ideoiden suhteen.';
$string['colles8short'] = 'Olen kriittinen lukemani suhteen';
$string['colles9'] = 'Selitn ideani muille opiskelijoille';
$string['colles9short'] = 'Selitn ideani';
$string['collesaintro'] = 'Tmn kyselyn tarkoituksena on selvitt, kuinka hyvin tm online-kurssi on auttanut sinua oppimaan.

Jokainen seuravista 24 kysymyksest koskee sinun kokemuksiasi tll kursilla.

Ei ole olemassa oikeata tai vri vastauksia, tahdomme sinun mielipiteesi asioista. Muista ett vastaukset ksitelln luottamuksellisesti, eivtk ne vaikuta arvosteluun.

Vastaamalla huolellisesti ja ajatuksella autat meit parantamaan tt kurssia tulevaisuudessa.

Kiitokset avustasi.';
$string['collesaname'] = 'COLLES toteutunut (actual)';
$string['collesapintro'] = 'Tmn kyselyn tarkoituksena on selvitt kuinka hyvin tm online-kurssi on auttanut sinua oppimaan.

Jokainen seuravista 24 kysymyksest pyyt sina vertaamaan <i>ideaalia</i> ja <i>toteutunutta</i> tilannetta kurssilla.

Ei ole olemassa oikeata tai vri vastauksia, tahdomme sinun mielipiteesi asioista. Muista, ett vastaukset ksitelln luottamuksellisesti, eivtk ne vaikuta arvosteluun.

Vastaamalla huolellisesti ja ajatuksella autat meit parantamaan tt kurssia tulevaisuudessa.';
$string['collesapname'] = 'COLLES (Haluttu ja Toteutunut)';
$string['collesm1'] = 'Relevanssi';
$string['collesm1short'] = 'Relevanssi';
$string['collesm2'] = 'Heijastuminen';
$string['collesm2short'] = 'Heijastuminen';
$string['collesm3'] = 'Vuorovaikutteisuus';
$string['collesm3short'] = 'Vuorovaikutteisuus';
$string['collesm4'] = 'Ohjaajan tuki';
$string['collesm4short'] = 'Ohjaajan tuki';
$string['collesm5'] = 'Vertaistuki';
$string['collesm5short'] = 'Vertaistuki';
$string['collesm6'] = 'Tulkinta';
$string['collesm6short'] = 'Tulkinta';
$string['collesmintro'] = 'Tll kurssilla ...';
$string['collespintro'] = 'Tmn kyselyn tarkoituksena on selvit, mit asiaoita arvostat online-oppimisympristss.

Jokainen seuraavasta 24 kysymyksest kysyy sinun  odotuksistasi tlt kurssilta.
Ei ole olemassa oikeata tai vri vastauksia, tahdomme sinun mielipiteesi asioista. Muista ett vastaukset ksitelln luottamuksellisesti, eivtk ne vaikuta arvosteluun.

Vastaamalla huolellisesti ja ajatuksella autat meit parantamaan tt kurssia tulevaisuudessa.';
$string['collespname'] = 'COLLES haluttu (preferred) ';
$string['done'] = 'Tehty';
$string['download'] = 'Lataa';
$string['downloadexcel'] = 'Lataa tiedot Excel-taulukkona';
$string['downloadinfo'] = 'Voit ladata kaikki kyselyn tiedot analysointia varten. Voit kytt tietoja Excel-, SPPS- tai muussa ohjelmissa.';
$string['downloadtext'] = 'Lataa tiedot tekstitiedostona.';
$string['editingasurvey'] = 'Kyselynn muokkaus';
$string['guestsnotallowed'] = 'Kysely ei ole tarkoitettu vieraille';
$string['helpsurveys'] = 'Opastus eri kyselytyyppeihin';
$string['howlong'] = 'Kauanko sinulta meni aikaa kyselyyn vastaamiseen?';
$string['howlongoptions'] = 'alle 1 min,1-2 min,2-3 min,3-4 min,4-5-min,5-10 min,yli 10 min';
$string['ifoundthat'] = 'Huomasin tll kursilla, ett';
$string['introtext'] = 'Johdanto';
$string['ipreferthat'] = 'Olisi hyv, ett';
$string['modulename'] = 'Kysely';
$string['modulenameplural'] = 'Kyselyt';
$string['name'] = 'Nimi';
$string['newsurveyresponses'] = 'Uudet kyselyn vastaukset';
$string['nobodyyet'] = 'Kukaan ei ole viel vastannut kyselyyn';
$string['notdone'] = 'Suorittamatta';
$string['notes'] = 'Oma (henkilkohtainen) analyysisi ja muistiinpanosi.';
$string['othercomments'] = 'Onko sinulla muita kommentteja?';
$string['peoplecompleted'] = '$a henkil on suorittanut tmn kyselyn';
$string['preferred'] = 'Haluttu';
$string['preferredclass'] = 'Haluttu';
$string['preferredstudent'] = '$a haluttu';
$string['question'] = 'Kysymys';
$string['questions'] = 'Kysymykset';
$string['questionsnotanswered'] = 'Joihinkin monivalintoihin ei ole vastattu.';
$string['report'] = 'Kyselyn raportti';
$string['savednotes'] = 'Muistiinpanosi tallennettiin';
$string['scaleagree5'] = 'Vahvasti erimielt, Jotakuinkin erimielt, Ei samaa tai eri mielt, Jotakuinkin samaa mielt, Vahvasti samaa mielt';
$string['scales'] = 'Asteikot';
$string['scaletimes5'] = 'Ei koskaan, Harvoin, Joskus, Usein, Miltei aina';
$string['seemoredetail'] = 'Napsauta tst nhdksesi listietoja ';
$string['selectedquestions'] = 'Valitut kysymykset, kaikki opiskelijat';
$string['summary'] = 'Yhteenveto';
$string['surveycompleted'] = 'Olet vastannut thn kyselyyn. Alla olevasta kuvasta net yhteenvedon vastauksistasi verrattuna kurssin keskiarvoon.';
$string['surveyname'] = 'Kyselyn nimi';
$string['surveysaved'] = 'Kysely tallennettu';
$string['surveytype'] = 'Kyselyn tyyppi';
$string['thanksforanswers'] = 'Kiitos vastauksestasi thn kyselyyn, $a';
$string['time'] = 'Aika';
$string['viewsurveyresponses'] = 'Katso $a kyselyn vastausta';

?>
